@@ -5,7 +5,7 @@ package Dahdi::Hardware::PCI;
 # This program is free software; you can redistribute and/or
 # modify it under the same terms as Perl itself.
 #
-# $Id: PCI.pm 6313 2009-04-02 20:56:42Z tzafrir $
+# $Id: PCI.pm 7469 2009-11-04 13:39:15Z tzafrir $
 #
 use strict;
 use Dahdi::Utils;
@@ -85,7 +85,7 @@ my %pci_ids = (
 	'd161:8001'		=> { DRIVER => 'wcte12xp', DESCRIPTION => 'Wildcard TE122' },
 
 	# from wcb4xxp
-	'd161:b410'             => { DRIVER => 'wcb4xxp', DESCRIPTION => 'Digium Wildcard B410P' },
+	'd161:b410'		=> { DRIVER => 'wcb4xxp', DESCRIPTION => 'Digium Wildcard B410P' },
 
 	# from tor2
 	'10b5:9030'		=> { DRIVER => 'tor2', DESCRIPTION => 'PLX 9030' },
@@ -93,6 +93,9 @@ my %pci_ids = (
 	'10b5:d00d'		=> { DRIVER => 'tor2', DESCRIPTION => 'Tormenta 2 Quad T1/PRI or E1/PRA' },
 	'10b5:4000'		=> { DRIVER => 'tor2', DESCRIPTION => 'Tormenta 2 Quad T1/E1 (non-Digium clone)' },
 
+	# # from wctc4xxp
+	'd161:3400'		=> { DRIVER => 'wctc4xxp', DESCRIPTION => 'Wildcard TC400P' },
+
 	# Cologne Chips:
 	# (Still a partial list)
 	'1397:08b4/b556'	=> { DRIVER => 'qozap', DESCRIPTION => 'Junghanns DuoBRI ISDN card' },
